[![license](https://img.shields.io/badge/license-MIT-brightgreen)](https://spdx.org/licenses/MIT.html)
[![pipelines](https://gitlab.com/cappysan/nwn-dg/badges/master/pipeline.svg?ignore_skipped=true)](https://gitlab.com/cappysan/nwn-dg/pipelines)
[![coverage](https://gitlab.com/cappysan/nwn-dg/badges/master/coverage.svg)](/coverage/index.html)

# nwn-dg

Work in progress: in alpha stage.

Neverwinter Nights (nwn) dungeon generator


## Installation

You can install the latest version from PyPI package repository.

~~~bash
python3 -mpip install -U nwn-dg
# or
pipx install nwn-dg
~~~


## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.


## Locations

  * Website: [https://gitlab.com/cappysan/nwn-dg](https://gitlab.com/cappysan/nwn-dg)
  * PyPi: [https://pypi.org/project/nwn_dg](https://pypi.org/project/nwn_dg)
